#
# spec file for package sqlitebrowser
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sqlitebrowser
Version:        3.7.0
Release:        5.3
Summary:        Create, design and edit SQLite Databases
License:        GPL-3.0+ or MPL-2.0
Group:          Productivity/Office/Organizers
Url:            https://github.com/rp-/sqlitebrowser/
# https://github.com/rp-/sqlitebrowser/releases
Source0:        %{name}-%{version}.tar.gz
Source1:        sqlitebrowser.1
%if 0%{?suse_version}
BuildRequires:  update-desktop-files
%endif
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  sqlite3-devel
BuildRequires:  update-desktop-files
%if 0%{?suse_version} > 1320
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
%else
BuildRequires:  libqt4-devel
%endif
%if 0%{?suse_version} > 1100
BuildRequires:  pkgconfig(glib-2.0)
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
SQLite Database Browser is a freeware, public domain, open source visual tool
used to create, design and edit database files compatible with SQLite. It is
meant to be used for users and developers that want to create databases, edit
and search data using a familiar spreadsheet-like interface, without the need
to learn complicated SQL commands. Controls and wizards are available for users
to:

	* Create and compact database files
	* Create, define, modify and delete tables
	* Create, define and delete indexes
	* Browse, edit, add and delete records
	* Search records
	* Import and export records as text
	* Import and export tables from/to CSV files
	* Import and export databases from/to SQL dump files
	* Issue SQL queries and inspect the results
	* Examine a log of all SQL commands issued by the application

%prep
%setup -q

%build
export CXXFLAGS="%optflags"
cmake \
%if 0%{?suse_version} > 1320
-DUSE_QT5=true \
%endif
-DCMAKE_INSTALL_PREFIX=%{_prefix} .
make %{?_smp_mflags} VERBOSE=1

%install
make DESTDIR="%{buildroot}" install
mkdir -p %{buildroot}/%{_bindir} %{buildroot}/%{_datadir}/{applications,pixmaps}
install -Dm644 %{SOURCE1} %{buildroot}/%{_mandir}/man1/%{name}.1
install -m644 images/%{name}.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png
cat > %{buildroot}/%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Categories=Application;Network;GNOME;GTK;System;X-SuSE-ServiceConfiguration;
StartupNotify=true
Exec=%{_bindir}/%{name}
Name=%{name}
GenericName=SQLite Database browser
Terminal=false
Type=Application
Icon=%{name}
EOF
%if 0%{?suse_version}
%suse_update_desktop_file %{name}
%endif

%clean
rm -fr %{buildroot}

%if 0%{?suse_version} > 1130
%post
%desktop_database_post

%postun
%desktop_database_postun
%endif

%files
%defattr(-,root,root)
%doc README.md LICENSE currentrelease
%{_mandir}/man1/%{name}.1*
%{_bindir}/*
%{_datadir}/applications/*
%dir %{_datadir}/appdata
%{_datadir}/appdata/%{name}.desktop.appdata.xml
%{_datadir}/pixmaps/*
%{_datadir}/icons/hicolor/*/apps/sqlitebrowser.png

%changelog
* Thu Aug 13 2015 stephan.barth@suse.com
- update to version 3.7.0
  * Among many bug fixes 3.7.0 also contains these upstream enhancements:
  - Add option to remember last location for file dialogs
  - Add option for setting the font used in the SQL code editor
  - Preserve filters in Browse Data tab when changing tabs
  - Allow setting the line type and the point shape in the plot area
  - Add a 'Copy Create statement' popup action to Database Browser tab
    See the full list of 3.7.0 changes under
    https://github.com/sqlitebrowser/sqlitebrowser/releases/tag/v3.7.0
  * Major new features that were added by upstream for version 3.6.0:
  - Better SQL export
  - REGEXP support (see the wiki page for details...)
  - NULL value highlighting - customisable in the preferences
    See the full list of 3.6.0 changes under
    https://github.com/sqlitebrowser/sqlitebrowser/releases/tag/v3.6.0
* Tue Apr 28 2015 crrodriguez@opensuse.org
- Use QT5 for Factory builds
- Honour RPM_OPT_FLAGS.
* Thu Apr  2 2015 mpluskal@suse.com
- Update licensing information
* Thu Mar 26 2015 stephan.barth@suse.com
- Update to version 3.5.1 from 3.4.0
  Upstream changes for 3.5.1:
  Bug fixes
  - Default Location field can't be changed in v3.5.0 on OSX - #197
  - Crash when a table name is empty - #194
  - CSV Import bug - final row being missed - #193
  - Attach database when main is encrypted - #174
  - Failure to delete some SQLite entries (.s3db) - #172
  Important upstream changes for 3.5.0:
  One of the major improvements in this release, is support for encrypted
  databases. This is done using the SQLCipher encryption library.
  Enhancements
  - I18N - Simplified Chinese language support - #138
  - Add tooltip for all table items - #139
  - Remember CSV export options - #149
  - Distinguish Save and Save As when saving SQL files in the Execute SQL tab
  - #152
  - Add two buttons to navigate to the head and the tail - #169
  - Support Indices without sorting - #176
  Enhancements with progress, though more still needs to be done
  - Open Encrypted Database - #12
  - Add full support for tables without rowid - #51
  - NULL field values are not highlighted - #163
  - Ability to change language - #182 #187
  Bug fixes
  - Foreign Key in Edit Create Table - #109
  - CSV export bug - Fields aren't automatically quoted when separator
    character is present in the data - #144
  - [feature request]"Execute SQL": clear output if query returns nothing -
  - #151
  - Export to SQL INT Datatype Expression - #156
  - Crash when opening db without rowid and composite primary key - #159
  - Database Structure view: wrong parsing of CHECK constraints - #179
  - tests: fix QCoreApplication parameters #185
* Mon Dec  8 2014 lars@linux-schulserver.de
- update to 3.4.0
  + CSV file import and export code has been extensively modified
    for better RFC compatibility
  + support for custom collation sequences. This lets people use
    SQLite3 databases copied from their Android phone or tablet.
  + several fixes in our SQL grammar parser
  + Make adding new rows less confusing by showing automatically
    generated data by default values, triggers or the PK right after
    the new row is added
  + Edit Table dialog: Add option for adding a unique constraint to columns
  + UI improvements: Show line numbers in the SQL log
  + Add a database schema pane (can be torn off)
  + Added a Russian translation, fixed German translation
  + new Project files feature, for saving metadata about your SQLite
    Database files
  + New: Plotting, a quick and dirty way to draw graphs from your
    table data
  + Bi-licensed under MPLv2 and GPLv3
- adapt package license string for the bi-license
- use cmake now instead of old qmake
- let make install the sqlitebrowser binary
- build-require hicolor-icon-theme for the directory ownership
* Sun Feb 16 2014 lars@linux-schulserver.de
- update to 3.0.2:
  + Fix a memory leak
  + Allow space characters in table and index names, disallow ` chars
  + Update execute query table view when no results returned
  + Fix non tables/column names with non ascii characters
* Sun Dec 15 2013 lars@linux-schulserver.de
- update to 3.0.1:
  + key names in table/column names
  + copy/paste of single cell
* Thu Nov  7 2013 lars@linux-schulserver.de
- update to 3.0:
  + Qt3Support was removed
  + Recent files menu added
  + Improved UI, making it more modern, replacing some dialogs etc.
  + Syntax highlighting for SQL code
  + Cleaned up the code, reducing the SLOC quite a bit
  + Added basic support for triggers and views
  + Added pragma editing
  + Added BLOB support
  + Added a new filter row for searching
  + Improved performance when opening large tables
  + Extended the SQL tab
  + Added SQLite extension support
  + Fixed a ton of bugs
  + Probably more
- removed edittableform-fix-qdebug-use.patch
- removed sqlitebrowser-libs.patch
* Thu Sep 29 2011 lars@linux-schulserver.de
- add -ldl to the linker (sqlitebrowser-libs.patch)
* Thu Aug 25 2011 lars@linux-schulserver.de
- initial version 2.0b1, but using SVN revision 69 instead
